@@ -51,7 +51,7 @@ them.
 
 package Data::Properties;
 
-$VERSION = '0.02';
+$VERSION = '1.06';
 
 use strict;
 use POSIX ();
@@ -354,7 +354,9 @@ http://java.sun.com/j2se/1.3/docs/api/index.html
 
 =head1 AUTHOR
 
-Brian Moseley, bcm@maz.org
+Brian Moseley, bcm@maz.org (original version).
+
+Johan Vromans, jv@cpan.org (revived version).
 
 =cut
 
